@@ -3,7 +3,7 @@
 namespace PhpParser;
 
 class JsonDecoderTest extends \PHPUnit\Framework\TestCase {
-    public function testRoundTrip() {
+    public function testRoundTrip(): void {
         $code = <<<'PHP'
 <?php
 // comment
@@ -23,14 +23,14 @@ PHP;
     }
 
     /** @dataProvider provideTestDecodingError */
-    public function testDecodingError($json, $expectedMessage) {
+    public function testDecodingError($json, $expectedMessage): void {
         $jsonDecoder = new JsonDecoder();
         $this->expectException(\RuntimeException::class);
         $this->expectExceptionMessage($expectedMessage);
         $jsonDecoder->decode($json);
     }
 
-    public function provideTestDecodingError() {
+    public static function provideTestDecodingError() {
         return [
             ['???', 'JSON decoding error: Syntax error'],
             ['{"nodeType":123}', 'Node type must be a string'],
