@@ -245,6 +245,9 @@ fn(array $a): array => $a;
 fn(A $a): A => $a;
 fn(?A $a): ?A => $a;
 
+#[X]
+const EXAMPLE = true;
+
 A::b();
 A::$b;
 A::B;
@@ -283,12 +286,18 @@ class A extends \NS\B implements \NS\C, \NS\D
     public const \X\Foo C = \X\Foo::Bar;
     public \NS\Foo $foo {
         #[\NS\X]
-        set(#[\NS\X] \NS\Bar $v) {
+        set(
+            #[\NS\X]
+            \NS\Bar $v
+        ) {
         }
     }
     public function __construct(public \NS\Foo $bar {
         #[\NS\X]
-        set(#[\NS\X] \NS\Bar $v) {
+        set(
+            #[\NS\X]
+            \NS\Bar $v
+        ) {
         }
     })
     {
@@ -312,7 +321,10 @@ trait A
 {
 }
 #[\NS\X]
-function f(#[\NS\X] \NS\A $a): \NS\A
+function f(
+    #[\NS\X]
+    \NS\A $a
+): \NS\A
 {
 }
 function f2(array $a): array
@@ -329,6 +341,8 @@ function fn4(?array $a): ?array
 #[\NS\X] fn(array $a): array => $a;
 fn(\NS\A $a): \NS\A => $a;
 fn(?\NS\A $a): ?\NS\A => $a;
+#[\NS\X]
+const EXAMPLE = true;
 \NS\A::b();
 \NS\A::$b;
 \NS\A::B;
