@@ -3,9 +3,9 @@
 namespace PhpParser\Parser;
 
 use PhpParser\Lexer;
-use PhpParser\ParserTest;
+use PhpParser\ParserTestAbstract;
 
-class Php8Test extends ParserTest
+class Php8Test extends ParserTestAbstract
 {
     protected function getParser(Lexer $lexer) {
         return new Php8($lexer);
